complete -c arch-audit -n "__fish_use_subcommand" -s C -l color -d 'Bypass tty detection for colors' -r -f -a "auto always never"
complete -c arch-audit -n "__fish_use_subcommand" -s b -l dbpath -d 'Set an alternate database location'
complete -c arch-audit -n "__fish_use_subcommand" -s f -l format -d 'Specify a format to control the output. Placeholders are %n (pkgname), %c (CVEs), %v (fixed version), %t (type), %s (severity), and %r (required by, only when -r is also used)'
complete -c arch-audit -n "__fish_use_subcommand" -l source -d 'Specify the URL or file path to the security tracker json data'
complete -c arch-audit -n "__fish_use_subcommand" -l proxy -d 'Send requests through a proxy'
complete -c arch-audit -n "__fish_use_subcommand" -l sort -d 'Specify how to sort the output' -r -f -a "severity pkgname upgradable reverse"
complete -c arch-audit -n "__fish_use_subcommand" -s q -l quiet -d 'Show only vulnerable package names and their versions. Set twice to hide the versions as well'
complete -c arch-audit -n "__fish_use_subcommand" -s r -l recursive -d 'Prints packages that depend on vulnerable packages and are thus potentially vulnerable as well. Set twice to show ALL the packages that requires them'
complete -c arch-audit -n "__fish_use_subcommand" -s t -l show-testing -d 'Show packages which are in the [testing] repos. See https://wiki.archlinux.org/index.php/Official_repositories#Testing_repositories'
complete -c arch-audit -n "__fish_use_subcommand" -s u -l upgradable -d 'Show only packages that have already been fixed'
complete -c arch-audit -n "__fish_use_subcommand" -l json -d 'Print json output'
complete -c arch-audit -n "__fish_use_subcommand" -l no-proxy -d 'Do not use a proxy even if one is configured'
complete -c arch-audit -n "__fish_use_subcommand" -s c -l show-cve -d 'Print the CVE numbers'
complete -c arch-audit -n "__fish_use_subcommand" -s h -l help -d 'Prints help information'
complete -c arch-audit -n "__fish_use_subcommand" -s V -l version -d 'Prints version information'
complete -c arch-audit -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions'
complete -c arch-audit -n "__fish_use_subcommand" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c arch-audit -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Prints help information'
complete -c arch-audit -n "__fish_seen_subcommand_from completions" -s V -l version -d 'Prints version information'
complete -c arch-audit -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c arch-audit -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
